// <copyright file="GetRealmsCommand.cs" company="Selenium Committers">
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
// </copyright>

namespace OpenQA.Selenium.BiDi.Script;

internal sealed class GetRealmsCommand(GetRealmsParameters @params)
    : Command<GetRealmsParameters, GetRealmsResult>(@params, "script.getRealms");

internal sealed record GetRealmsParameters(BrowsingContext.BrowsingContext? Context, RealmType? Type) : Parameters;

public sealed record GetRealmsOptions : CommandOptions
{
    public BrowsingContext.BrowsingContext? Context { get; init; }

    public RealmType? Type { get; init; }
}

public sealed record ContextGetRealmsOptions : CommandOptions
{
    public RealmType? Type { get; init; }

    internal static GetRealmsOptions WithContext(ContextGetRealmsOptions? options, BrowsingContext.BrowsingContext context) => new()
    {
        Context = context,
        Type = options?.Type,
        Timeout = options?.Timeout
    };
}

public sealed record GetRealmsResult(IReadOnlyList<RealmInfo> Realms) : EmptyResult;
